@@ -25,10 +25,9 @@ VERSION = __version__
 CONFIG_ADDON = os.getenv('CONFIG_ADDON', 'config.free')
 
 
-class Settings():
-
+class Settings(object):
     def __init__(self, api_url=None, token_source_url=None, ssh_forwarder_url=None, env=os.environ):
-        self.ssh_forwarder = ssh_forwarder_url or env.pop('SSH_FORWARDER', 'sshforwarder.cloudcontrolled.com')
+        self.ssh_forwarder = ssh_forwarder_url or env.get('SSH_FORWARDER', 'sshforwarder.cloudcontrolled.com')
         self.ssh_forwarder_port = '2222'
-        self.api_url = api_url or env.pop('CCTRL_API_URL', 'https://api.cloudcontrol.com')
+        self.api_url = api_url or env.get('CCTRL_API_URL', 'https://api.cloudcontrolled.com')
         self.token_source_url = token_source_url or self.api_url + '/token/'
